﻿;-----------------------------------------------------------------------
; photobooth_greenscreen_backgrounds.ahk
;
; AutoHotkey script to automatically switch green screen backgrounds and overlays
; when keys on the numberpad are pressed.
;
; Usage: Name the green screen backgrounds in the photo booth images folder gs1.jpg, gs2.jpg,
; gs3.jpg etc. Green screen overlay files, if used, should be named gs1.png, gs2.png, gs3.png etc.
; Run this script by double clicking on it in Windows Explorer then press the number pad keys
; switch backgrounds and overlays. Numpad 1 to 9 select gs1.jpg to gs9.jpg and numpad 0, del,
; enter, / and * select gs10.jpg to gs.14.jpg. Numpad + and - cycle up or down through the
; backgrounds.
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; Written by Chris Breeze, www.breezesys.com
;-----------------------------------------------------------------------

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
#SingleInstance force
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

count = 1

; Only apply macros if photo booth is running
#IfWinExist,Breeze Systems Photobooth -

NumPad1::
NumPadEnd::
CopyBackground(1)
return

NumPad2::
NumPadDown::
CopyBackground(2)
return

NumPad3::
NumPadPgDn::
CopyBackground(3)
return

NumPad4::
NumPadLeft::
CopyBackground(4)
return

NumPad5::
NumPadClear::
CopyBackground(5)
return

NumPad6::
NumPadRight::
CopyBackground(6)
return

NumPad7::
NumPadHome::
CopyBackground(7)
return

NumPad8::
NumPadUp::
CopyBackground(8)
return

NumPad9::
NumPadPgUp::
CopyBackground(9)
return

NumPad0::
NumPadIns::
CopyBackground(10)
return

NumPadDot::
NumPadDel::
CopyBackground(11)
return

NumPadEnter::
CopyBackground(12)
return

NumPadDiv::
CopyBackground(13)
return

NumPadMult::
CopyBackground(14)
return

; Number pad '+' key selects next background
NumPadAdd::
WinGetTitle,Title,Breeze Systems Photobooth -
If Title contains ready.jpg
{
	RegExMatch(Title, "Breeze Systems Photobooth - (.*\\)(.*ready\.jpg)", output) 
	i := count + 1
	bg = %output1%gs%i%.jpg
	IfNotExist,%bg%
	{
		i := 1
	}
	CopyBackground(i)
}
return

; Number pad '-' key selects previous background
NumPadSub::
WinGetTitle,Title,Breeze Systems Photobooth -
If Title contains ready.jpg
{
	RegExMatch(Title, "Breeze Systems Photobooth - (.*\\)(.*ready\.jpg)", output) 
	i := count - 1
	bg = %output1%gs%i%.jpg
	IfNotExist,%bg%
	{
		i := 1
		bg = %output1%gs%i%.jpg
		While FileExist(bg)
		{
			i++
			bg = %output1%gs%i%.jpg
		}
		i--
	}
	CopyBackground(i)
}
return

CopyBackground(id)
{
	global count
	WinGetTitle,WinTitle,Breeze Systems Photobooth -
	If WinTitle contains video_ready.jpg
	{
		return
	}

	If WinTitle contains ready.jpg
	{
		RegExMatch(WinTitle, "Breeze Systems Photobooth - (.*\\)(.*ready\.jpg)", dir) 
		srcFile = %dir1%gs%id%.jpg
		destFile = %dir1%greenscreen_background.jpg
		srcOverlayFile = %dir1%gs%id%.png
		destOverlayFile = %dir1%greenscreen_overlay.png
		IfExist,%srcFile%
		{
			count = %id%	; update count so that numpad +/- can cycle through the backgrounds
			FileCopy,%srcFile%,%destFile%,1	

			; copy overlay file too
			IfExist,%srcOverlayFile%
			{
				FileCopy,%srcOverlayFile%,%destOverlayFile%,1	
			}
			else
			{
				; new background doesn't have an overlay - delete current overlay
				FileDelete,%destOverlayFile%
			}
		}
	}

}
